@@ -2504,6 +2504,20 @@ function isShiftPressed() {
     return getKeyboardModifiers().valueOf() & Qt.ShiftModifier.valueOf();
 };
 
+// Qt 4 API workaround:
+function qsTranslate2(context, sourceText, disambiguation, n) {
+    if (RSettings.isQt(4)) {
+        if (isNull(disambiguation)) {
+            return qsTranslate(context, sourceText);
+        }
+        if (isNull(n)) {
+            return qsTranslate(context, sourceText, disambiguation);
+        }
+        return qsTranslate(context, sourceText, disambiguation, "UnicodeUTF8", n);
+    }
+    return qsTranslate(context, sourceText, disambiguation, n);
+}
+
 // fix QPlainTextEdit API for Qt 5:
 if (!isFunction(QPlainTextEdit.prototype.toPlainText)) {
     QPlainTextEdit.prototype.toPlainText = function() {
